@@ -71,28 +71,33 @@ def auto_upgrade():
 
     current = version.Version(__version__)
     latest_str = fetch_latest()
+    latest = None
     try:
         latest = version.Version(latest_str)
-    except version.VersionError:
+    except (version.VersionError, TypeError):
         print("Failed to parse %s version: %s" % (_pypi_project, latest_str))
-        latest = None
 
     log_upgrade_check_time()
 
-    if not latest or not latest > current:
+    if not latest:
+        print("Auto upgrade failed.")
+        return
+
+    if not latest > current:  # already latest
         return
 
     if latest.major > current.major:
         print("Major version bumped, not safe to upgrade automatically.")
         return
 
+    print("Auto upgrading rezup (%s) .." % str(latest))
     upgrade()
     restart()
 
 
 def upgrade():
     args = [
-        sys.executable, "-m", "pip", "install", "--upgrade",
+        sys.executable, "-m", "pip", "install", "-qq", "--upgrade",
         _local_upgrade_source or _pypi_project
     ]
     subprocess.check_call(args)
